==> FileSystemStorage-2.5.1.tgz: FileSystemStorage/patches.py <==
## -*- coding: utf-8 -*-
## Copyright (C) 2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""
$Id: $
"""

__author__  = ''
__docformat__ = 'restructuredtext'

# Patch __bobo_traverse__ method of BaseObject in AT product
# Make the following example works
# Example : 
# You have an ATobject in ZODB at /mysite/myobject
# This object has an ImageField (image) using FSS
# Doing /mysite/myobject/image should get the image
PATCH = False
from Products.Archetypes.BaseObject import BaseObject
from Products.FileSystemStorage.utils import getFieldValue

if not PATCH:
    old_bobo_traverse = BaseObject.__bobo_traverse__
    def new_bobo_traverse(self, REQUEST, name):
        """Access to field values that are not using AttributeStorage
        """
        
        try:
            return old_bobo_traverse(self, REQUEST, name)
        except AttributeError:
            return getFieldValue(self, name)
            
    BaseObject.__bobo_traverse__ = new_bobo_traverse
    PATCH = True

==> FileSystemStorage-2.5.2.tgz: FileSystemStorage/patches.py <==
# -*- coding: utf-8 -*-
## FileSystemStorage
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""Patch __bobo_traverse__ method of BaseObject in AT product

Make the following example works
Example :
You have an ATobject in ZODB at /mysite/myobject
This object has an ImageField (image) using FSS
Doing /mysite/myobject/image should get the image
"""
__version__ = "$Revision:  $"
# $Source:  $
# $Id:  $
__docformat__ = 'restructuredtext'


FSS_BOBO_PATCH = False
from Products.Archetypes.BaseObject import BaseObject
from Products.FileSystemStorage.utils import getFieldValue

if not FSS_BOBO_PATCH:
    old_bobo_traverse = BaseObject.__bobo_traverse__
    def new_bobo_traverse(self, REQUEST, name):
        """Access to field values that are not using AttributeStorage
        """

        try:
            return old_bobo_traverse(self, REQUEST, name)
        except AttributeError:
            return getFieldValue(self, name)

    BaseObject.__bobo_traverse__ = new_bobo_traverse
    FSS_BOBO_PATCH = True
